<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Event\Form\Models\Question;
use EventPortal\Domain\Event\Form\Models\QuestionOption;
use EventPortal\Domain\Event\Form\Models\QuestionValidation;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class QuestionTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_get_question_types(): void
    {
        $this->assertEquals([
            [
                'label' => 'Single choice answer',
                'value' => 'RadioButtons',
            ],
            [
                'label' => 'Multiple choice answers',
                'value' => 'Checkboxes',
            ],
            [
                'label' => 'Dropdown',
                'value' => 'Select',
            ],
            [
                'label' => 'Single line text box',
                'value' => 'TextInput',
            ],
            [
                'label' => 'Paragraph text box',
                'value' => 'TextArea',
            ],
            [
                'label' => 'Date',
                'value' => 'DateInput',
            ],
            [
                'label' => 'Time',
                'value' => 'TimeInput',
            ],
        ], Question::typesAsOptions());
    }

    /** @test **/
    public function deletes_option_and_validation_when_deleting_question(): void
    {
        $question = factory(Question::class)->create();
        factory(QuestionOption::class)->create(['question_id' => $question->id]);
        factory(QuestionValidation::class)->create(['question_id' => $question->id]);

        $question->delete();

        $this->assertCount(0, QuestionOption::all());
        $this->assertCount(0, QuestionValidation::all());
    }
}
